<?php
/**
 * Sumo functions and definitions
 *
 * @package Sumo
 */

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
function sumo_theme_setup() {

	add_theme_support( 'omega-footer-widgets', 3 );

	add_action ('omega_header', 'sumo_header_right');

	add_action( 'widgets_init', 'sumo_widgets_init', 15 );

	/* Register custom menus. */
	add_action( 'init', 'sumo_register_menu' );

	remove_theme_support( 'theme-layouts' );

	add_action( 'omega_footer', 'sumo_footer_links' );

	add_action( 'wp_enqueue_scripts', 'sumo_scripts_styles' );

}

add_action( 'after_setup_theme', 'sumo_theme_setup', 11  );

/**
 * Enqueque Google Font
 *
 * @since 1.0.1
 */

function sumo_scripts_styles() {
	$query_args = array(
	 'family' => 'Lato:400'
	);
 	wp_enqueue_style( 'google-fonts', add_query_arg( $query_args, "//fonts.googleapis.com/css" ), array(), null  );
}

/**
 * Sets a common class, `.omega-nav-menu`, for the custom menu widget if used in the header right sidebar.
 *
 * @since 1.0.0
 *
 * @param  array $args Header menu args.
 *
 * @return array $args Modified header menu args.
 */
function sumo_menu_args( $args ) {

	$args['container']   = 'div';
	$args['menu_class'] .= ' omega-nav-menu';

	return $args;

}

function sumo_header_right() {

	add_filter( 'wp_nav_menu_args', 'sumo_menu_args' );
	if ( is_active_sidebar( 'header-right' ) ) : ?>	

	<aside class="header-right widget-area sidebar">
		
		<?php dynamic_sidebar( 'header-right' ); ?>

  	</aside><!-- .sidebar -->

	<?php endif; 
	remove_filter( 'wp_nav_menu_args', 'sumo_menu_args' );
}

/**
 * Register widgetized area and update sidebar with default widgets
 */
function sumo_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Header Right', 'sumo' ),
		'id'            => 'header-right',
		'before_widget' => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  => '</div></section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}

function sumo_register_menu() {
	register_nav_menu( 'social',   _x( 'Social', 'nav menu location', 'sumo' ) );
}

function sumo_footer_links() {

	if ( has_nav_menu( 'social' ) ) {

		wp_nav_menu(
			array(
				'theme_location'  => 'social',
				'container'       => 'div',
				'container_id'    => 'menu-social',
				'container_class' => 'menu',
				'menu_id'         => 'menu-social-items',
				'menu_class'      => 'menu-items',
				'depth'           => 1,
				'link_before'     => '<span class="screen-reader-text">',
				'link_after'      => '</span>',
				'fallback_cb'     => '',
			)
		);
	}
}